@@ -1,8 +1,6 @@
 .dbEnv <- new.env()
 
 .onLoad <- function(lib, pkg) {
-    if(!require(stashR, quietly = TRUE))
-        stop("'stashR' package required")
     stashROption("quietDownload", TRUE)
 }
 
@@ -10,8 +8,7 @@
     dcf <- read.dcf(file.path(lib, pkg, "DESCRIPTION"))
     msg <- gettextf("%s (%s %s)", dcf[, "Title"],
                     as.character(dcf[, "Version"]), dcf[, "Date"])
-    message(paste(strwrap(msg), collapse = "\n"))
-    message(paste(strwrap(gettext("Initialize database using 'initMCAPS'")),
-                  collapse = "\n"))
+    packageStartupMessage(paste(strwrap(msg), collapse = "\n"))
+    packageStartupMessage("Initialize database using 'initMCAPS'")
 }
 
